# MITTEN: MultIvariate sTatisTical procEss coNtrol
A package for MSPC modeling.
Current supports:
- MCUSUM
- MEWMA
- Principle Component MEWMA
- Hotelling's $T^2$
- Univariate Diagnostic t-tests

## TODO
Function Docstrings:
- [ ]  diagnostics.py
- [ ]  hotelling.py
- [ ]  mcusum.py
- [ ]  mewma.py